@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 use Moose;
 
@@ -138,7 +138,7 @@ Dist::Zilla::Plugin::Author::SKIRMESS::RepositoryBase - Automatically create and
 
 =head1 VERSION
 
-Version 0.013
+Version 0.014
 
 =head1 SYNOPSIS
 
@@ -674,18 +674,6 @@ version_all_ok;
 done_testing();
 XT_AUTHOR_TEST_VERSION_T
 
-=head2 xt/release/changes.t
-
-L<Test::CPAN::Changes|Test::CPAN::Changes> release test.
-
-=cut
-
-    $file{q{xt/release/changes.t}} = $test_header . <<'XT_RELEASE_CHANGES_T';
-use Test::CPAN::Changes;
-
-changes_ok();
-XT_RELEASE_CHANGES_T
-
 =head2 xt/release/eol.t
 
 L<Test::EOL|Test::EOL> release test.
